@@ -25,7 +25,8 @@ import ConfigParser
 
 from TrayIcon import TrayIcon
 
-from more import get_sid, get_view_params, _print, get_icon
+from more import get_sid, get_view_params, _print, get_icon, get_system_rgb
+    
 from MainClass import ApiClient
 from calculate.consolegui.datavars import DataVarsGui
 from pid_information import client_pid_info
@@ -287,7 +288,6 @@ class ToolTabWidget(qt.QTabWidget):
         self.FirstWidget = ClientObj.MainWidget
 
         self.PlusWidget = qt.QWidget(self)
-
         self.tabbar = MyTabBar(self)
         self.setTabBar(self.tabbar)
 
@@ -297,7 +297,6 @@ class ToolTabWidget(qt.QTabWidget):
 
         self.addTab(self.FirstWidget, self.gui_icon , self.new_con_txt)
         self.addTab(self.PlusWidget, self.other_icon, '')
-
         self.last_close_index = -1
         self.tabCloseRequested.connect(self.close_tab)
         self.currentChanged.connect(self.add_tab)
@@ -307,6 +306,7 @@ class ToolTabWidget(qt.QTabWidget):
         self.setTabsClosable(True)
         self.tabbar.tabButton(1, qt.QTabBar.RightSide).hide()
 
+
         if not self.get_size():
             # definition of screen resolution
             prim_screen = self.app.desktop().primaryScreen()
@@ -321,21 +321,19 @@ class ToolTabWidget(qt.QTabWidget):
         self.setMinimumWidth(500)
 
         self.setWindowTitle(self.Name)
+
+        hbg = get_system_rgb(self, qt.QPalette.Base)
+        bg = "transparent"
+        leftpadding = 8
+        width = 24
         self.setStyleSheet('''
         QTabBar::tab:last {
-        background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,
-                                    stop: 0 #E1E1E1, stop: 0.4 #DDDDDD,
-                                    stop: 0.5 #D8D8D8, stop: 1.0 #D3D3D3);
-        border: 2px solid #C4C4C3;
-        border-bottom-color: #C2C7CB; border-top-left-radius: 4px;
-        border-top-right-radius: 4px; padding-left: 3px;
-
-        margin-left: 3px; margin-bottom: 5px; margin-top: 2px; width: 18px;}
-        QTabBar::tab:last::hover {background: 
-                            qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,
-                            stop: 0 #E9E9E9, stop: 0.4 #E5E5E5,
-                            stop: 0.5 #E1E1E1, stop: 1.0 #DDDDDD);}
-                            ''')
+        background: %s;
+        margin: 2px 2px 3px 0px;
+        width: %s;
+        padding: 0px 0px 0px %spx;}
+        QTabBar::tab:last::hover {
+            background: %s;}''' % (bg, width, leftpadding, hbg))
 
         self.set_offline_icon()
         self.show()
